/*
 * Project: Examples for GJA course
 * Author: Ing. Jaroslav Dytrych idytrych@fit.vutbr.cz
 * File: FormServlet.java
 * Description: Example servlet for form processing
 */

/**
 * @file FormServlet.java
 *
 * @brief Example servlet for form processing
 */

/**
 * @package cz.vutbr.fit.knot.gja.formProcessing.server
 * 
 * @brief Example of form processing
 */
package cz.vutbr.fit.knot.gja.formProcessing.server;

import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Example class for form processing
 *
 * @brief Example class for form processing
 */
@WebServlet(name = "FormServlet", urlPatterns = {"/FormServlet"})
public class FormServlet extends HttpServlet {

  /**
   * The serialization runtime associates with each serializable class 
   * a version number, called a serialVersionUID, which is used during 
   * deserialization to verify that the sender and receiver of a serialized 
   * object have loaded classes for that object that are compatible with 
   * respect to serialization.
   * https://docs.oracle.com/javase/7/docs/api/java/io/Serializable.html
   */
  private static final long serialVersionUID = 4213286061127378249L;

  /**
   * Processes requests for both HTTP
   * <code>GET</code> and
   * <code>POST</code> methods.
   *
   * @param request servlet request
   * @param response servlet response
   * @throws ServletException if a servlet-specific error occurs
   * @throws IOException if an I/O error occurs
   */
  protected void processRequest(HttpServletRequest request, HttpServletResponse response)
                                throws ServletException, IOException {
    response.setContentType("text/html;charset=UTF-8");
    
    String userName = request.getParameter("username");
    String password = request.getParameter("password");
    String bio = request.getParameter("bio");
    String country = request.getParameter("country");
    String subscribeForNewsletter = request.getParameter("newsletter");
    String receiveMail = request.getParameter("receivemail");
    String reveiveNotifications = request.getParameter("receivenotification");

    response.setContentType("text/html");

    PrintWriter writer = response.getWriter();
    writer.write("<h2> You have entered following values </h2>");
    writer.write("<br/>");
    writer.write("<table>");
    startTableRow(writer);
    addTableColumn(writer, "username");
    addTableColumn(writer, userName);
    closeTableRow(writer);

    startTableRow(writer);
    addTableColumn(writer, "password");
    addTableColumn(writer, password);
    closeTableRow(writer);

    startTableRow(writer);
    addTableColumn(writer, "Bio");
    addTableColumn(writer, bio);
    closeTableRow(writer);

    startTableRow(writer);
    addTableColumn(writer, "Country");
    addTableColumn(writer, country);
    closeTableRow(writer);

    startTableRow(writer);
    addTableColumn(writer, "Subscribe for news letter");
    addTableColumn(writer, subscribeForNewsletter);
    closeTableRow(writer);

    startTableRow(writer);
    addTableColumn(writer, "Receive mail from members");
    addTableColumn(writer, receiveMail);
    closeTableRow(writer);

    startTableRow(writer);
    addTableColumn(writer, "Receive notification");
    addTableColumn(writer, reveiveNotifications);
    closeTableRow(writer);

    writer.write("</table>");

    writer.close();

  }

  /**
   * Starts table row
   * 
   * @param writer Output writer to be used
   */
  private static void startTableRow(PrintWriter writer) {
    writer.write("<tr>");
  }

  /**
   * Ends table row
   * 
   * @param writer Output writer to be used
   */
  private static void closeTableRow(PrintWriter writer) {
    writer.write("</tr>");
  }

  /**
   * Creates table cell
   * 
   * @param writer Output writer to be used
   * @param value Cell content
   */
  private static void addTableColumn(PrintWriter writer, String value) {
    writer.write("<td> " + value + "</td>");
  }

  // <editor-fold defaultstate="collapsed" desc="HttpServlet methods. Click on the + sign on the left to edit the code.">
  /**
   * Handles the HTTP
   * <code>GET</code> method.
   *
   * @param request servlet request
   * @param response servlet response
   * @throws ServletException if a servlet-specific error occurs
   * @throws IOException if an I/O error occurs
   */
  @Override
  protected void doGet(HttpServletRequest request, HttpServletResponse response)
          throws ServletException, IOException {
    processRequest(request, response);
  }

  /**
   * Handles the HTTP
   * <code>POST</code> method.
   *
   * @param request servlet request
   * @param response servlet response
   * @throws ServletException if a servlet-specific error occurs
   * @throws IOException if an I/O error occurs
   */
  @Override
  protected void doPost(HttpServletRequest request, HttpServletResponse response)
          throws ServletException, IOException {
    processRequest(request, response);
  }

  /**
   * Returns a short description of the servlet.
   *
   * @return a String containing servlet description
   */
  @Override
  public String getServletInfo() {
    return "Example servlet for form processing";
  }// </editor-fold>
}  // public class FormServlet
